You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tv...@apache.org on 2013/08/25 16:17:28 UTC

svn commit: r1517295 [10/15] - in /commons/proper/jcs/trunk: ./ auxiliary-builds/javagroups/src/java/org/apache/commons/ auxiliary-builds/javagroups/src/java/org/apache/jcs/auxiliary/javagroups/ auxiliary-builds/javagroups/src/test/org/apache/commons/ ...

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/lru/LRUMemoryCache.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/lru/LRUMemoryCache.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/lru/LRUMemoryCache.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/lru/LRUMemoryCache.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.memory.lru;
+package org.apache.commons.jcs.engine.memory.lru;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,9 +22,9 @@ package org.apache.jcs.engine.memory.lru
 import java.io.IOException;
 import java.io.Serializable;
 
-import org.apache.jcs.engine.behavior.ICacheElement;
-import org.apache.jcs.engine.memory.AbstractDoubleLinkedListMemoryCache;
-import org.apache.jcs.engine.memory.util.MemoryElementDescriptor;
+import org.apache.commons.jcs.engine.behavior.ICacheElement;
+import org.apache.commons.jcs.engine.memory.AbstractDoubleLinkedListMemoryCache;
+import org.apache.commons.jcs.engine.memory.util.MemoryElementDescriptor;
 
 /**
  * A fast reference management system. The least recently used items move to the end of the list and

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/mru/MRUMemoryCache.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/mru/MRUMemoryCache.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/mru/MRUMemoryCache.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/mru/MRUMemoryCache.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.memory.mru;
+package org.apache.commons.jcs.engine.memory.mru;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,9 +22,9 @@ package org.apache.jcs.engine.memory.mru
 import java.io.IOException;
 import java.io.Serializable;
 
-import org.apache.jcs.engine.behavior.ICacheElement;
-import org.apache.jcs.engine.memory.AbstractDoubleLinkedListMemoryCache;
-import org.apache.jcs.engine.memory.util.MemoryElementDescriptor;
+import org.apache.commons.jcs.engine.behavior.ICacheElement;
+import org.apache.commons.jcs.engine.memory.AbstractDoubleLinkedListMemoryCache;
+import org.apache.commons.jcs.engine.memory.util.MemoryElementDescriptor;
 
 /**
  * The most recently used items move to the front of the list and get spooled to disk if the cache

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/package.html (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/memory/package.html)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/package.html?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/package.html&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/memory/package.html&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
    (empty)

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/package.html
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.1

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/package.html
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/package.html
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/shrinking/ShrinkerThread.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/shrinking/ShrinkerThread.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/shrinking/ShrinkerThread.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/shrinking/ShrinkerThread.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.memory.shrinking;
+package org.apache.commons.jcs.engine.memory.shrinking;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -24,15 +24,15 @@ import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Set;
 
+import org.apache.commons.jcs.engine.behavior.ICacheElement;
+import org.apache.commons.jcs.engine.behavior.IElementAttributes;
+import org.apache.commons.jcs.engine.control.event.ElementEvent;
+import org.apache.commons.jcs.engine.control.event.behavior.ElementEventType;
+import org.apache.commons.jcs.engine.control.event.behavior.IElementEvent;
+import org.apache.commons.jcs.engine.control.event.behavior.IElementEventHandler;
+import org.apache.commons.jcs.engine.memory.behavior.IMemoryCache;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.engine.behavior.ICacheElement;
-import org.apache.jcs.engine.behavior.IElementAttributes;
-import org.apache.jcs.engine.control.event.ElementEvent;
-import org.apache.jcs.engine.control.event.behavior.ElementEventType;
-import org.apache.jcs.engine.control.event.behavior.IElementEvent;
-import org.apache.jcs.engine.control.event.behavior.IElementEventHandler;
-import org.apache.jcs.engine.memory.behavior.IMemoryCache;
 
 /**
  * A background memory shrinker. Memory problems and concurrent modification exception caused by

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/util/MemoryElementDescriptor.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/util/MemoryElementDescriptor.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/util/MemoryElementDescriptor.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/memory/util/MemoryElementDescriptor.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.memory.util;
+package org.apache.commons.jcs.engine.memory.util;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -21,8 +21,8 @@ package org.apache.jcs.engine.memory.uti
 
 import java.io.Serializable;
 
-import org.apache.jcs.engine.behavior.ICacheElement;
-import org.apache.jcs.utils.struct.DoubleLinkedListNode;
+import org.apache.commons.jcs.engine.behavior.ICacheElement;
+import org.apache.commons.jcs.utils.struct.DoubleLinkedListNode;
 
 /**
  * This wrapper is needed for double linked lists.

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/package.html (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/package.html)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/package.html?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/package.html&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/package.html&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
    (empty)

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/package.html
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.1

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/package.html
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/package.html
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/CacheStats.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/CacheStats.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/CacheStats.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/CacheStats.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/CacheStats.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/CacheStats.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/CacheStats.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.stats;
+package org.apache.commons.jcs.engine.stats;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -19,9 +19,9 @@ package org.apache.jcs.engine.stats;
  * under the License.
  */
 
-import org.apache.jcs.engine.stats.behavior.ICacheStats;
-import org.apache.jcs.engine.stats.behavior.IStatElement;
-import org.apache.jcs.engine.stats.behavior.IStats;
+import org.apache.commons.jcs.engine.stats.behavior.ICacheStats;
+import org.apache.commons.jcs.engine.stats.behavior.IStatElement;
+import org.apache.commons.jcs.engine.stats.behavior.IStats;
 
 /**
  * This class stores cache historical and statistics data for a region.

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/CacheStats.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.2

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/CacheStats.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/CacheStats.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/StatElement.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/StatElement.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/StatElement.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/StatElement.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/StatElement.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/StatElement.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/StatElement.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.stats;
+package org.apache.commons.jcs.engine.stats;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -19,7 +19,7 @@ package org.apache.jcs.engine.stats;
  * under the License.
  */
 
-import org.apache.jcs.engine.stats.behavior.IStatElement;
+import org.apache.commons.jcs.engine.stats.behavior.IStatElement;
 
 /**
  * This is a stat data holder.

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/StatElement.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.2

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/StatElement.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/StatElement.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/Stats.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/Stats.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/Stats.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/Stats.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/Stats.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/engine/stats/Stats.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/Stats.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.stats;
+package org.apache.commons.jcs.engine.stats;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -19,8 +19,8 @@ package org.apache.jcs.engine.stats;
  * under the License.
  */
 
-import org.apache.jcs.engine.stats.behavior.IStatElement;
-import org.apache.jcs.engine.stats.behavior.IStats;
+import org.apache.commons.jcs.engine.stats.behavior.IStatElement;
+import org.apache.commons.jcs.engine.stats.behavior.IStats;
 
 /**
  * @author aaronsm

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/Stats.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.2

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/Stats.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/Stats.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/ICacheStats.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/ICacheStats.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/ICacheStats.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/ICacheStats.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.stats.behavior;
+package org.apache.commons.jcs.engine.stats.behavior;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/IStatElement.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/IStatElement.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/IStatElement.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/IStatElement.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.stats.behavior;
+package org.apache.commons.jcs.engine.stats.behavior;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/IStats.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/IStats.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/IStats.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/engine/stats/behavior/IStats.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.engine.stats.behavior;
+package org.apache.commons.jcs.engine.stats.behavior;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/package.html (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/package.html)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/package.html?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/package.html&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/package.html&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
    (empty)

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/package.html
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.1

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/package.html
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/package.html
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/AbstractJCSWorkerHelper.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/AbstractJCSWorkerHelper.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/AbstractJCSWorkerHelper.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/AbstractJCSWorkerHelper.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.access;
+package org.apache.commons.jcs.utils.access;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/JCSWorker.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/JCSWorker.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/JCSWorkerHelper.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/JCSWorkerHelper.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.access;
+package org.apache.commons.jcs.utils.access;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/OptionConverter.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/OptionConverter.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/OptionConverter.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/OptionConverter.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.config;
+package org.apache.commons.jcs.utils.config;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/PropertySetter.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/PropertySetter.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/PropertySetter.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/PropertySetter.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.config;
+package org.apache.commons.jcs.utils.config;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/PropertySetterException.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/PropertySetterException.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/PropertySetterException.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/config/PropertySetterException.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.config;
+package org.apache.commons.jcs.utils.config;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/date/DateFormatter.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/date/DateFormatter.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/date/DateFormatter.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/date/DateFormatter.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.date;
+package org.apache.commons.jcs.utils.date;
 
 import java.text.ParseException;
 import java.util.Date;

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/date/ThreadSafeSimpleDateFormat.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/date/ThreadSafeSimpleDateFormat.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/date/ThreadSafeSimpleDateFormat.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/date/ThreadSafeSimpleDateFormat.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.date;
+package org.apache.commons.jcs.utils.date;
 
 import java.text.DateFormatSymbols;
 import java.text.FieldPosition;

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/DiscoveredService.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/DiscoveredService.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/DiscoveredService.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/DiscoveredService.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/DiscoveredService.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/DiscoveredService.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/DiscoveredService.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPCleanupRunner.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPCleanupRunner.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPCleanupRunner.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPCleanupRunner.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPCleanupRunner.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPCleanupRunner.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPCleanupRunner.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryAttributes.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryAttributes.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryAttributes.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryAttributes.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryAttributes.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryAttributes.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryAttributes.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryInfo.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryInfo.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryInfo.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryInfo.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryInfo.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryInfo.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryInfo.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryManager.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryManager.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryManager.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryManager.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryManager.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryManager.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryManager.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,12 +22,12 @@ package org.apache.jcs.utils.discovery;
 import java.util.HashMap;
 import java.util.Map;
 
+import org.apache.commons.jcs.engine.behavior.ICompositeCacheManager;
+import org.apache.commons.jcs.engine.behavior.IProvideScheduler;
+import org.apache.commons.jcs.engine.behavior.IShutdownObservable;
+import org.apache.commons.jcs.engine.logging.behavior.ICacheEventLogger;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.engine.behavior.ICompositeCacheManager;
-import org.apache.jcs.engine.behavior.IProvideScheduler;
-import org.apache.jcs.engine.behavior.IShutdownObservable;
-import org.apache.jcs.engine.logging.behavior.ICacheEventLogger;
 
 /**
  * This manages UDPDiscovery Services. We should end up with one service per Lateral Cache Manager

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryManager.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.2

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryManager.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryManager.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryMessage.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryMessage.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryMessage.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryMessage.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryMessage.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryMessage.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryMessage.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryMessage.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.2

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryMessage.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryMessage.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryReceiver.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryReceiver.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryReceiver.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryReceiver.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryReceiver.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryReceiver.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryReceiver.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -29,9 +29,9 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.ThreadFactory;
 import java.util.concurrent.ThreadPoolExecutor;
 
+import org.apache.commons.jcs.engine.behavior.IShutdownObserver;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.engine.behavior.IShutdownObserver;
 
 /** Receives UDP Discovery messages. */
 public class UDPDiscoveryReceiver

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryReceiver.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.3

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryReceiver.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryReceiver.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySender.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoverySender.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySender.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySender.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoverySender.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoverySender.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySender.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -26,9 +26,9 @@ import java.net.InetAddress;
 import java.net.MulticastSocket;
 import java.util.ArrayList;
 
+import org.apache.commons.jcs.utils.serialization.StandardSerializer;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.utils.serialization.StandardSerializer;
 
 /**
  * This is a generic sender for the UDPDiscovery process.

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySender.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.3

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySender.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySender.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySenderThread.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoverySenderThread.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySenderThread.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySenderThread.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoverySenderThread.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoverySenderThread.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySenderThread.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySenderThread.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.2

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySenderThread.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoverySenderThread.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Copied: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryService.java (from r1479115, commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryService.java)
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryService.java?p2=commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryService.java&p1=commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryService.java&r1=1479115&r2=1517295&rev=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/jcs/utils/discovery/UDPDiscoveryService.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryService.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery;
+package org.apache.commons.jcs.utils.discovery;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -27,13 +27,13 @@ import java.util.concurrent.CopyOnWriteA
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 
+import org.apache.commons.jcs.engine.behavior.IRequireScheduler;
+import org.apache.commons.jcs.engine.behavior.IShutdownObserver;
+import org.apache.commons.jcs.engine.logging.behavior.ICacheEventLogger;
+import org.apache.commons.jcs.utils.discovery.behavior.IDiscoveryListener;
+import org.apache.commons.jcs.utils.net.HostNameUtil;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.engine.behavior.IRequireScheduler;
-import org.apache.jcs.engine.behavior.IShutdownObserver;
-import org.apache.jcs.engine.logging.behavior.ICacheEventLogger;
-import org.apache.jcs.utils.discovery.behavior.IDiscoveryListener;
-import org.apache.jcs.utils.net.HostNameUtil;
 
 /**
  * This service creates a listener that can create lateral caches and add them to the no wait list.
@@ -114,7 +114,7 @@ public class UDPDiscoveryService
     }
 
     /**
-     * @see org.apache.jcs.engine.behavior.IRequireScheduler#setScheduledExecutorService(java.util.concurrent.ScheduledExecutorService)
+     * @see org.apache.commons.jcs.engine.behavior.IRequireScheduler#setScheduledExecutorService(java.util.concurrent.ScheduledExecutorService)
      */
     public void setScheduledExecutorService(ScheduledExecutorService scheduledExecutor)
     {

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryService.java
------------------------------------------------------------------------------
    cvs2svn:cvs-rev = 1.4

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryService.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/UDPDiscoveryService.java
------------------------------------------------------------------------------
    svn:keywords = Author Date Id Revision

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/behavior/IDiscoveryListener.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/behavior/IDiscoveryListener.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/behavior/IDiscoveryListener.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/discovery/behavior/IDiscoveryListener.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.discovery.behavior;
+package org.apache.commons.jcs.utils.discovery.behavior;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -19,7 +19,7 @@ package org.apache.jcs.utils.discovery.b
  * under the License.
  */
 
-import org.apache.jcs.utils.discovery.DiscoveredService;
+import org.apache.commons.jcs.utils.discovery.DiscoveredService;
 
 /**
  * Interface for things that want to listen to discovery events. This will allow discovery to be

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/key/KeyGeneratorUtil.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/key/KeyGeneratorUtil.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/key/KeyGeneratorUtil.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/key/KeyGeneratorUtil.java Sun Aug 25 14:17:11 2013
@@ -1,12 +1,12 @@
-package org.apache.jcs.utils.key;
+package org.apache.commons.jcs.utils.key;
 
 import java.text.ParseException;
 import java.util.Calendar;
 import java.util.Date;
 
+import org.apache.commons.jcs.utils.date.DateFormatter;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.utils.date.DateFormatter;
 
 /**
  * This can create and parse request ids.  You can use it to generate keys that contain a create time stamp.
@@ -84,7 +84,7 @@ public final class KeyGeneratorUtil
 
         Date d = new Date();
         String dateString = DateFormatter.getDddHHmm( d );
-        String finalOctetOfIp = org.apache.jcs.utils.net.AddressUtil.obtainFinalThreeDigitsOfAddressAsString();
+        String finalOctetOfIp = org.apache.commons.jcs.utils.net.AddressUtil.obtainFinalThreeDigitsOfAddressAsString();
         String queryId = leadNumber + dateString + finalOctetOfIp + counter;
         return queryId;
     }

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/net/AddressUtil.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/net/AddressUtil.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/net/AddressUtil.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/net/AddressUtil.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.net;
+package org.apache.commons.jcs.utils.net;
 
 import java.net.UnknownHostException;
 

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/net/HostNameUtil.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/net/HostNameUtil.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/net/HostNameUtil.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/net/HostNameUtil.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.net;
+package org.apache.commons.jcs.utils.net;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/AbstractPropertyContainer.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/AbstractPropertyContainer.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/AbstractPropertyContainer.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/AbstractPropertyContainer.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.props;
+package org.apache.commons.jcs.utils.props;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -21,7 +21,7 @@ package org.apache.jcs.utils.props;
 
 import java.util.Properties;
 
-import org.apache.jcs.access.exception.ConfigurationException;
+import org.apache.commons.jcs.access.exception.ConfigurationException;
 
 /**
  * Provides a mechanism to load properties into objects.

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertiesFactory.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertiesFactory.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertiesFactory.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertiesFactory.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.props;
+package org.apache.commons.jcs.utils.props;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertiesFactoryFileImpl.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertiesFactoryFileImpl.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertiesFactoryFileImpl.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertiesFactoryFileImpl.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.props;
+package org.apache.commons.jcs.utils.props;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertyLoader.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertyLoader.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertyLoader.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/props/PropertyLoader.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.props;
+package org.apache.commons.jcs.utils.props;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/CompressingSerializer.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/CompressingSerializer.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/CompressingSerializer.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/CompressingSerializer.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.serialization;
+package org.apache.commons.jcs.utils.serialization;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -27,8 +27,8 @@ import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.io.Serializable;
 
-import org.apache.jcs.engine.behavior.IElementSerializer;
-import org.apache.jcs.utils.zip.CompressionUtil;
+import org.apache.commons.jcs.engine.behavior.IElementSerializer;
+import org.apache.commons.jcs.utils.zip.CompressionUtil;
 
 /**
  * Performs default serialization and de-serialization. It gzips the value.

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/SerializationConversionUtil.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/SerializationConversionUtil.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/SerializationConversionUtil.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/SerializationConversionUtil.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.serialization;
+package org.apache.commons.jcs.utils.serialization;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,13 +22,13 @@ package org.apache.jcs.utils.serializati
 import java.io.IOException;
 import java.io.Serializable;
 
+import org.apache.commons.jcs.engine.CacheElement;
+import org.apache.commons.jcs.engine.CacheElementSerialized;
+import org.apache.commons.jcs.engine.behavior.ICacheElement;
+import org.apache.commons.jcs.engine.behavior.ICacheElementSerialized;
+import org.apache.commons.jcs.engine.behavior.IElementSerializer;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.engine.CacheElement;
-import org.apache.jcs.engine.CacheElementSerialized;
-import org.apache.jcs.engine.behavior.ICacheElement;
-import org.apache.jcs.engine.behavior.ICacheElementSerialized;
-import org.apache.jcs.engine.behavior.IElementSerializer;
 
 /**
  * This uses a supplied Serializer to convert to and from cache elements.

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/StandardSerializer.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/StandardSerializer.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/StandardSerializer.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/serialization/StandardSerializer.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.serialization;
+package org.apache.commons.jcs.utils.serialization;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -27,7 +27,7 @@ import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.io.Serializable;
 
-import org.apache.jcs.engine.behavior.IElementSerializer;
+import org.apache.commons.jcs.engine.behavior.IElementSerializer;
 
 /**
  * Performs default serialization and de-serialization.

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/servlet/JCSServletContextListener.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/servlet/JCSServletContextListener.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/servlet/JCSServletContextListener.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/servlet/JCSServletContextListener.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.servlet;
+package org.apache.commons.jcs.utils.servlet;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -22,10 +22,10 @@ package org.apache.jcs.utils.servlet;
 import javax.servlet.ServletContextEvent;
 import javax.servlet.ServletContextListener;
 
+import org.apache.commons.jcs.access.exception.CacheException;
+import org.apache.commons.jcs.engine.control.CompositeCacheManager;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.access.exception.CacheException;
-import org.apache.jcs.engine.control.CompositeCacheManager;
 
 /**
  * If you add this to the context listeners section of your web.xml file, this will shutdown JCS
@@ -36,7 +36,7 @@ import org.apache.jcs.engine.control.Com
  * <pre>
  *  &lt;listener&gt;
  *  &lt;listener-class&gt;
- *  org.apache.jcs.utils.servlet.JCSServletContextListener
+ *  org.apache.commons.jcs.utils.servlet.JCSServletContextListener
  *  &lt;/listener-class&gt;
  *  &lt;/listener&gt;
  * </pre>

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/BoundedQueue.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/BoundedQueue.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/BoundedQueue.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/BoundedQueue.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.struct;
+package org.apache.commons.jcs.utils.struct;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/DoubleLinkedList.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/DoubleLinkedList.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/DoubleLinkedList.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/DoubleLinkedList.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.struct;
+package org.apache.commons.jcs.utils.struct;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/DoubleLinkedListNode.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/DoubleLinkedListNode.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/DoubleLinkedListNode.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/DoubleLinkedListNode.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.struct;
+package org.apache.commons.jcs.utils.struct;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUElementDescriptor.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUElementDescriptor.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUElementDescriptor.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUElementDescriptor.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.struct;
+package org.apache.commons.jcs.utils.struct;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUMap.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUMap.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUMap.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUMap.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.struct;
+package org.apache.commons.jcs.utils.struct;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -30,13 +30,13 @@ import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
 
+import org.apache.commons.jcs.engine.control.group.GroupAttrName;
+import org.apache.commons.jcs.engine.stats.StatElement;
+import org.apache.commons.jcs.engine.stats.Stats;
+import org.apache.commons.jcs.engine.stats.behavior.IStatElement;
+import org.apache.commons.jcs.engine.stats.behavior.IStats;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.engine.control.group.GroupAttrName;
-import org.apache.jcs.engine.stats.StatElement;
-import org.apache.jcs.engine.stats.Stats;
-import org.apache.jcs.engine.stats.behavior.IStatElement;
-import org.apache.jcs.engine.stats.behavior.IStats;
 
 /**
  * This is a simple LRUMap. It implements most of the map methods. It is not recommended that you

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUMapEntry.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUMapEntry.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUMapEntry.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/LRUMapEntry.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.struct;
+package org.apache.commons.jcs.utils.struct;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/SingleLinkedList.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/SingleLinkedList.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/SingleLinkedList.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/SingleLinkedList.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.struct;
+package org.apache.commons.jcs.utils.struct;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/SortedPreferentialArray.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/SortedPreferentialArray.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/SortedPreferentialArray.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/struct/SortedPreferentialArray.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.struct;
+package org.apache.commons.jcs.utils.struct;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/threadpool/PoolConfiguration.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/threadpool/PoolConfiguration.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/threadpool/PoolConfiguration.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/threadpool/PoolConfiguration.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.threadpool;
+package org.apache.commons.jcs.utils.threadpool;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/threadpool/ThreadPoolManager.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/threadpool/ThreadPoolManager.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/threadpool/ThreadPoolManager.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/threadpool/ThreadPoolManager.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.threadpool;
+package org.apache.commons.jcs.utils.threadpool;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -28,10 +28,10 @@ import java.util.concurrent.ThreadFactor
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 
+import org.apache.commons.jcs.utils.props.PropertyLoader;
+import org.apache.commons.jcs.utils.threadpool.PoolConfiguration.WhenBlockedPolicy;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.utils.props.PropertyLoader;
-import org.apache.jcs.utils.threadpool.PoolConfiguration.WhenBlockedPolicy;
 
 /**
  * This manages threadpools for an application using Doug Lea's Util Concurrent package.

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/timing/ElapsedTimer.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/timing/ElapsedTimer.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/timing/ElapsedTimer.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/timing/ElapsedTimer.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.timing;
+package org.apache.commons.jcs.utils.timing;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/timing/SleepUtil.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/timing/SleepUtil.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/timing/SleepUtil.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/timing/SleepUtil.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.timing;
+package org.apache.commons.jcs.utils.timing;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/zip/CompressionUtil.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/zip/CompressionUtil.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/zip/CompressionUtil.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/zip/CompressionUtil.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.zip;
+package org.apache.commons.jcs.utils.zip;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one

Modified: commons/proper/jcs/trunk/src/scripts/remoteCacheStats.bat
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/scripts/remoteCacheStats.bat?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/scripts/remoteCacheStats.bat (original)
+++ commons/proper/jcs/trunk/src/scripts/remoteCacheStats.bat Sun Aug 25 14:17:11 2013
@@ -20,7 +20,7 @@ call prep.bat
 
 :run
 rem set DBUGPARM=-classic -Xdebug -Xnoagent -Djava.compiler=NONE -Xrunjdwp:transport=dt_socket,server=y,address=5000,suspend=n
-%JAVA_HOME%\bin\java %DBUGPARM% -ms10m -mx20m -classpath %CLASSPATH% "-Djava.security.policy=%CURDIR%\src\conf\cache.policy" org.apache.jcs.auxiliary.remote.server.RemoteCacheServerFactory -stats /remote.cache%1.ccf
+%JAVA_HOME%\bin\java %DBUGPARM% -ms10m -mx20m -classpath %CLASSPATH% "-Djava.security.policy=%CURDIR%\src\conf\cache.policy" org.apache.commons.jcs.auxiliary.remote.server.RemoteCacheServerFactory -stats /remote.cache%1.ccf
 
 
 

Modified: commons/proper/jcs/trunk/src/scripts/remoteCacheStats.sh
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/scripts/remoteCacheStats.sh?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/scripts/remoteCacheStats.sh (original)
+++ commons/proper/jcs/trunk/src/scripts/remoteCacheStats.sh Sun Aug 25 14:17:11 2013
@@ -38,7 +38,7 @@ ARGS="$HEAP $DEBUG $POLICY"
 
 echo $ARGS
 
-java  $ARGS org.apache.jcs.auxiliary.remote.server.RemoteCacheServerFactory -stats "$1"
+java  $ARGS org.apache.commons.jcs.auxiliary.remote.server.RemoteCacheServerFactory -stats "$1"
 
 
 

Modified: commons/proper/jcs/trunk/src/scripts/startRemoteCache.bat
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/scripts/startRemoteCache.bat?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/scripts/startRemoteCache.bat (original)
+++ commons/proper/jcs/trunk/src/scripts/startRemoteCache.bat Sun Aug 25 14:17:11 2013
@@ -23,6 +23,6 @@ rem set DBUGPARM=-classic -Xdebug -Xnoag
 
 rem -XX:+PrintTenuringDistribution
 
-java %DBUGPARM% -verbosegc  -ms10m -mx200m -classpath %CLASSPATH% "-Djava.security.policy=%CURDIR%\src\conf\cache.policy" org.apache.jcs.auxiliary.remote.server.RemoteCacheServerFactory /remote.cache%1.ccf
+java %DBUGPARM% -verbosegc  -ms10m -mx200m -classpath %CLASSPATH% "-Djava.security.policy=%CURDIR%\src\conf\cache.policy" org.apache.commons.jcs.auxiliary.remote.server.RemoteCacheServerFactory /remote.cache%1.ccf
 
 

Modified: commons/proper/jcs/trunk/src/scripts/startRemoteCache.sh
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/scripts/startRemoteCache.sh?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
Binary files - no diff available.

Modified: commons/proper/jcs/trunk/src/scripts/stopRemoteCache.bat
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/scripts/stopRemoteCache.bat?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/scripts/stopRemoteCache.bat (original)
+++ commons/proper/jcs/trunk/src/scripts/stopRemoteCache.bat Sun Aug 25 14:17:11 2013
@@ -19,7 +19,7 @@ rem under the License.
 call prep.bat
 
 :run
-rem org.apache.jcs.auxiliary.remote.server.RemoteCacheServerFactory
+rem org.apache.commons.jcs.auxiliary.remote.server.RemoteCacheServerFactory
 rem set DBUGPARM=-classic -Xdebug -Xnoagent -Djava.compiler=NONE -Xrunjdwp:transport=dt_socket,server=y,address=5000,suspend=n
-%JAVA_HOME%\bin\java %DBUGPARM% -ms1m -mx20m -classpath %CLASSPATH% "-Djava.security.policy=C:/dev/cache/props/cache.policy" org.apache.jcs.auxiliary.remote.server.RemoteCacheServerFactory -shutdown /remote.cache.ccf
+%JAVA_HOME%\bin\java %DBUGPARM% -ms1m -mx20m -classpath %CLASSPATH% "-Djava.security.policy=C:/dev/cache/props/cache.policy" org.apache.commons.jcs.auxiliary.remote.server.RemoteCacheServerFactory -shutdown /remote.cache.ccf
 

Modified: commons/proper/jcs/trunk/src/scripts/tester.bat
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/scripts/tester.bat?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/scripts/tester.bat (original)
+++ commons/proper/jcs/trunk/src/scripts/tester.bat Sun Aug 25 14:17:11 2013
@@ -21,7 +21,7 @@ call prep.bat
 rem-Dlog4j.configuration=I:/dev/jakarta-turbine-jcs/src/scripts/log4j.properties
 
 :run
-java -ms90m -mx400m -verbosegc org.apache.jcs.access.TestCacheAccess /cache%1.ccf  %2 %3 %4 %5
+java -ms90m -mx400m -verbosegc org.apache.commons.jcs.access.TestCacheAccess /cache%1.ccf  %2 %3 %4 %5
 
 
 

Modified: commons/proper/jcs/trunk/src/scripts/tester.sh
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/scripts/tester.sh?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/scripts/tester.sh (original)
+++ commons/proper/jcs/trunk/src/scripts/tester.sh Sun Aug 25 14:17:11 2013
@@ -32,4 +32,4 @@ done
 echo ${CLASSPATH}
 # -Xrunhprof:cpu=samples,depth=6,thread=y
 
-${JAVA_HOME}/bin/java  -ms90m -mx400m -verbosegc -classpath "${CLASSPATH}" org.apache.jcs.access.TestCacheAccess /cache$argv.ccf
+${JAVA_HOME}/bin/java  -ms90m -mx400m -verbosegc -classpath "${CLASSPATH}" org.apache.commons.jcs.access.TestCacheAccess /cache$argv.ccf

Modified: commons/proper/jcs/trunk/src/test-conf/TestARCCache.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/test-conf/TestARCCache.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/test-conf/TestARCCache.ccf (original)
+++ commons/proper/jcs/trunk/src/test-conf/TestARCCache.ccf Sun Aug 25 14:17:11 2013
@@ -18,13 +18,13 @@
 # with the memory shrinker on.
 
 jcs.default=
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=10
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.arc.ARCMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.arc.ARCMemoryCache
 jcs.default.cacheattributes.UseMemoryShrinker=false
 jcs.default.cacheattributes.MaxMemoryIdleTimeSeconds=3600
 jcs.default.cacheattributes.ShrinkerIntervalSeconds=1
-jcs.default.elementattributes=org.apache.jcs.engine.ElementAttributes
+jcs.default.elementattributes=org.apache.commons.jcs.engine.ElementAttributes
 jcs.default.elementattributes.IsEternal=true
 jcs.default.elementattributes.MaxLifeSeconds=600
 jcs.default.elementattributes.IdleTime=1800

Modified: commons/proper/jcs/trunk/src/test-conf/TestBDBJEDiskCacheCon.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/test-conf/TestBDBJEDiskCacheCon.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/test-conf/TestBDBJEDiskCacheCon.ccf (original)
+++ commons/proper/jcs/trunk/src/test-conf/TestBDBJEDiskCacheCon.ccf Sun Aug 25 14:17:11 2013
@@ -18,46 +18,46 @@
 # a maximum of 100 objects, so objects should get pushed into the disk cache
 
 jcs.default=indexedDiskCache
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=100
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 # SYSTEM GROUP ID CACHE
 jcs.system.groupIdCache=indexedDiskCache
-jcs.system.groupIdCache.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.system.groupIdCache.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.system.groupIdCache.cacheattributes.MaxObjects=10000
-jcs.system.groupIdCache.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.system.groupIdCache.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 # #### CACHE REGIONS FOR TEST
 
 jcs.region.indexedRegion1=indexedDiskCache
-jcs.region.indexedRegion1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.indexedRegion1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.indexedRegion1.cacheattributes.MaxObjects=100
-jcs.region.indexedRegion1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.indexedRegion1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.indexedRegion2=indexedDiskCache
-jcs.region.indexedRegion2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.indexedRegion2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.indexedRegion2.cacheattributes.MaxObjects=100
-jcs.region.indexedRegion2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.indexedRegion2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.indexedRegion3=indexedDiskCache
-jcs.region.indexedRegion3.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.indexedRegion3.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.indexedRegion3.cacheattributes.MaxObjects=100
-jcs.region.indexedRegion3.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.indexedRegion3.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.indexedRegion4=indexedDiskCache
-jcs.region.indexedRegion4.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.indexedRegion4.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.indexedRegion4.cacheattributes.MaxObjects=100
-jcs.region.indexedRegion4.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.indexedRegion4.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 jcs.region.indexedRegion4.cacheattributes.UseMemoryShrinker=false
 
 
 # #### AUXILIARY CACHES
 
 # Berkeley DB JE
-jcs.auxiliary.indexedDiskCache=org.apache.jcs.auxiliary.disk.bdbje.BDBJECacheFactory
-jcs.auxiliary.indexedDiskCache.attributes=org.apache.jcs.auxiliary.disk.bdbje.BDBJECacheAttributes
+jcs.auxiliary.indexedDiskCache=org.apache.commons.jcs.auxiliary.disk.bdbje.BDBJECacheFactory
+jcs.auxiliary.indexedDiskCache.attributes=org.apache.commons.jcs.auxiliary.disk.bdbje.BDBJECacheAttributes
 jcs.auxiliary.indexedDiskCache.attributes.DiskPath=target/test-sandbox/bdbje-disk-cache-conc
 
 # #############################################################

Modified: commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCache.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCache.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCache.ccf (original)
+++ commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCache.ccf Sun Aug 25 14:17:11 2013
@@ -18,50 +18,50 @@
 # a maximum of 100 objects, so objects should get pushed into the disk cache
 
 jcs.default=blockDiskCache
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=100
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 # SYSTEM GROUP ID CACHE
 jcs.system.groupIdCache=blockDiskCache
-jcs.system.groupIdCache.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.system.groupIdCache.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.system.groupIdCache.cacheattributes.MaxObjects=10000
-jcs.system.groupIdCache.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.system.groupIdCache.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 # #### CACHE REGIONS FOR TEST
 
 jcs.region.blockRegion1=blockDiskCache
-jcs.region.blockRegion1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion1.cacheattributes.MaxObjects=100
-jcs.region.blockRegion1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.blockRegion2=blockDiskCache
-jcs.region.blockRegion2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion2.cacheattributes.MaxObjects=100
-jcs.region.blockRegion2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.blockRegion3=blockDiskCache
-jcs.region.blockRegion3.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion3.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion3.cacheattributes.MaxObjects=100
-jcs.region.blockRegion3.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion3.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.blockRegion4=blockDiskCache2
-jcs.region.blockRegion4.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion4.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion4.cacheattributes.MaxObjects=100
-jcs.region.blockRegion4.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion4.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 # #### AUXILIARY CACHES
 
 # Block Disk Cache
-jcs.auxiliary.blockDiskCache=org.apache.jcs.auxiliary.disk.block.BlockDiskCacheFactory
-jcs.auxiliary.blockDiskCache.attributes=org.apache.jcs.auxiliary.disk.block.BlockDiskCacheAttributes
+jcs.auxiliary.blockDiskCache=org.apache.commons.jcs.auxiliary.disk.block.BlockDiskCacheFactory
+jcs.auxiliary.blockDiskCache.attributes=org.apache.commons.jcs.auxiliary.disk.block.BlockDiskCacheAttributes
 jcs.auxiliary.blockDiskCache.attributes.DiskPath=target/test-sandbox/block-disk-cache
 
 # Block Disk Cache
-jcs.auxiliary.blockDiskCache2=org.apache.jcs.auxiliary.disk.block.BlockDiskCacheFactory
-jcs.auxiliary.blockDiskCache2.attributes=org.apache.jcs.auxiliary.disk.block.BlockDiskCacheAttributes
+jcs.auxiliary.blockDiskCache2=org.apache.commons.jcs.auxiliary.disk.block.BlockDiskCacheFactory
+jcs.auxiliary.blockDiskCache2.attributes=org.apache.commons.jcs.auxiliary.disk.block.BlockDiskCacheAttributes
 jcs.auxiliary.blockDiskCache2.attributes.DiskPath=target/test-sandbox/block-disk-cache2
 
 # #############################################################

Modified: commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCacheCon.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCacheCon.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCacheCon.ccf (original)
+++ commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCacheCon.ccf Sun Aug 25 14:17:11 2013
@@ -18,40 +18,40 @@
 # a maximum of 100 objects, so objects should get pushed into the disk cache
 
 jcs.default=blockDiskCache
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=100
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 
 # #### CACHE REGIONS FOR TEST
 
 jcs.region.blockRegion1=blockDiskCache
-jcs.region.blockRegion1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion1.cacheattributes.MaxObjects=100
-jcs.region.blockRegion1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.blockRegion2=blockDiskCache
-jcs.region.blockRegion2.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion2.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion2.cacheattributes.MaxObjects=100
-jcs.region.blockRegion2.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion2.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.blockRegion3=blockDiskCache
-jcs.region.blockRegion3.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion3.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion3.cacheattributes.MaxObjects=100
-jcs.region.blockRegion3.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion3.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 jcs.region.blockRegion4=blockDiskCache
-jcs.region.blockRegion4.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion4.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion4.cacheattributes.MaxObjects=100
-jcs.region.blockRegion4.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion4.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 # #### AUXILIARY CACHES
 
 # Block Disk Cache
-jcs.auxiliary.blockDiskCache=org.apache.jcs.auxiliary.disk.block.BlockDiskCacheFactory
-jcs.auxiliary.blockDiskCache.attributes=org.apache.jcs.auxiliary.disk.block.BlockDiskCacheAttributes
+jcs.auxiliary.blockDiskCache=org.apache.commons.jcs.auxiliary.disk.block.BlockDiskCacheFactory
+jcs.auxiliary.blockDiskCache.attributes=org.apache.commons.jcs.auxiliary.disk.block.BlockDiskCacheAttributes
 jcs.auxiliary.blockDiskCache.attributes.DiskPath=target/test-sandbox/block-disk-cache-conc
 jcs.auxiliary.blockDiskCache.attributes.MaxPurgatorySize=10000
 jcs.auxiliary.blockDiskCache.attributes.MaxKeySize=10000

Modified: commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCacheHuge.ccf
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCacheHuge.ccf?rev=1517295&r1=1517294&r2=1517295&view=diff
==============================================================================
--- commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCacheHuge.ccf (original)
+++ commons/proper/jcs/trunk/src/test-conf/TestBlockDiskCacheHuge.ccf Sun Aug 25 14:17:11 2013
@@ -18,24 +18,24 @@
 # a maximum of 0 objects, so objects should get pushed into the disk cache
 
 jcs.default=blockDiskCache
-jcs.default.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.default.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.default.cacheattributes.MaxObjects=0
-jcs.default.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.default.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 # #### CACHE REGIONS FOR TEST
 
 jcs.region.blockRegion1=blockDiskCache
-jcs.region.blockRegion1.cacheattributes=org.apache.jcs.engine.CompositeCacheAttributes
+jcs.region.blockRegion1.cacheattributes=org.apache.commons.jcs.engine.CompositeCacheAttributes
 jcs.region.blockRegion1.cacheattributes.MaxObjects=0
-jcs.region.blockRegion1.cacheattributes.MemoryCacheName=org.apache.jcs.engine.memory.lru.LRUMemoryCache
+jcs.region.blockRegion1.cacheattributes.MemoryCacheName=org.apache.commons.jcs.engine.memory.lru.LRUMemoryCache
 
 
 # #### AUXILIARY CACHES
 
 # Block Disk Cache
-jcs.auxiliary.blockDiskCache=org.apache.jcs.auxiliary.disk.block.BlockDiskCacheFactory
-jcs.auxiliary.blockDiskCache.attributes=org.apache.jcs.auxiliary.disk.block.BlockDiskCacheAttributes
+jcs.auxiliary.blockDiskCache=org.apache.commons.jcs.auxiliary.disk.block.BlockDiskCacheFactory
+jcs.auxiliary.blockDiskCache.attributes=org.apache.commons.jcs.auxiliary.disk.block.BlockDiskCacheAttributes
 jcs.auxiliary.blockDiskCache.attributes.DiskPath=target/test-sandbox/block-disk-cache-huge
 jcs.auxiliary.blockDiskCache.attributes.MaxPurgatorySize=300000
 jcs.auxiliary.blockDiskCache.attributes.MaxKeySize=1000000
--- commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/JCSWorker.java (original)
+++ commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/JCSWorker.java Sun Aug 25 14:17:11 2013
@@ -1,4 +1,4 @@
-package org.apache.jcs.utils.access;
+package org.apache.commons.jcs.utils.access;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -23,16 +23,16 @@ import java.io.Serializable;
 import java.util.HashMap;
 import java.util.Map;
 
+import org.apache.commons.jcs.JCS;
+import org.apache.commons.jcs.access.exception.CacheException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.jcs.JCS;
-import org.apache.jcs.access.exception.CacheException;
 
 /**
  * Utility class to encapsulate doing a piece of work, and caching the results
  * in JCS. Simply construct this class with the region name for the Cache and
  * keep a static reference to it instead of the JCS itself. Then make a new
  * org.apache.jcs.utils.access.AbstractJCSWorkerHelper and implement Object
  * doWork() and do the work in there, returning the object to be cached. Then
  * call .getResult() with the key and the AbstractJCSWorkerHelper to get the
  * result of the work. If the object isn't already in the Cache,
@@ -23,16 +23,16 @@ import java.io.Serializable;
  * in JCS. Simply construct this class with the region name for the Cache and
  * keep a static reference to it instead of the JCS itself. Then make a new
- * org.apache.jcs.utils.access.AbstractJCSWorkerHelper and implement Object
+ * org.apache.commons.jcs.utils.access.AbstractJCSWorkerHelper and implement Object
  * doWork() and do the work in there, returning the object to be cached. Then
  * call .getResult() with the key and the AbstractJCSWorkerHelper to get the

Modified: commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/JCSWorkerHelper.java
URL: http://svn.apache.org/viewvc/commons/proper/jcs/trunk/src/java/org/apache/commons/jcs/utils/access/JCSWorkerHelper.java?rev=1517295&r1=1479115&r2=1517295&view=diff
==============================================================================